@@ -20,7 +20,7 @@ use Module::Load::Conditional   qw[check_install];
 use version;
 
 use vars qw[$VERSION];
-$VERSION = "0.9904";
+$VERSION = "0.9914";
 
 =pod
 
@@ -115,31 +115,11 @@ An example entry would like this:
 
     ### default host list
     $Conf->{'conf'}->{'hosts'} = [
-            {
-                'scheme' => 'ftp',
-                'path' => '/pub/CPAN/',
-                'host' => 'ftp.cpan.org'
-            },
             {
                 'scheme' => 'http',
                 'path' => '/',
                 'host' => 'www.cpan.org'
             },
-            {
-                'scheme' => 'ftp',
-                'path' => '/',
-                'host' => 'cpan.hexten.net'
-            },
-            {
-                'scheme' => 'ftp',
-                'path' => '/CPAN/',
-                'host' => 'cpan.cpantesters.org'
-            },
-            {
-                'scheme' => 'ftp',
-                'path' => '/pub/languages/perl/CPAN/',
-                'host' => 'ftp.funet.fi'
-            }
         ];
 
 =item allow_build_interactivity
